# Neuphonic plugin for LiveKit Agents

Support for voice synthesis with [Neuphonic](https://neuphonic.com).

See [https://docs.livekit.io/agents/integrations/tts/neuphonic/](https://docs.livekit.io/agents/integrations/tts/neuphonic/) for more information.

## Installation

```bash
pip install livekit-plugins-neuphonic
```

## Pre-requisites

You'll need an API key from Neuphonic. It can be set as an environment variable: `NEUPHONIC_API_TOKEN`
